@@ -32,7 +32,8 @@ with this program. If not, see <https://www.gnu.org/licenses/>
 #include <stdlib.h>
 #include <inttypes.h>
 
-static bool gl_seen = false;
+static bool glx_seen = false;
+static bool egl_seen = false;
 static bool vk_seen = false;
 static struct gl_funcs gl_f;
 static struct egl_funcs egl_f;
@@ -108,8 +109,11 @@ static struct gl_data data;
 
 static bool gl_init_funcs(bool glx)
 {
-    if (gl_seen) {
-        return glx ? glx_f.valid && x11_f.valid : egl_f.valid;
+    if (glx && glx_seen) {
+        return glx_f.valid && x11_f.valid;
+    }
+    if (!glx && egl_seen) {
+        return egl_f.valid;
     }
 
     hlog("Init %s %s (%s)", glx ? "GLX" : "EGL", PLUGIN_VERSION,
@@ -119,11 +123,6 @@ static bool gl_init_funcs(bool glx)
         "32bit");
 #endif
 
-    gl_seen = true;
-    egl_f.valid = false;
-    glx_f.valid = false;
-    x11_f.valid = false;
-
     vkcapture_glvulkan = getenv("OBS_VKCAPTURE_GLVULKAN");
 
     capture_init();
@@ -132,6 +131,9 @@ static bool gl_init_funcs(bool glx)
     data.glx = glx;
 
     if (glx) {
+        glx_seen = true;
+        glx_f.valid = false;
+        x11_f.valid = false;
         void *handle = dlopen("libGLX.so.0", RTLD_LAZY);
         if (!handle) {
             hlog("Failed to open libGLX.so.0");
@@ -180,6 +182,8 @@ static bool gl_init_funcs(bool glx)
         GETXADDR(xcb_dri3_buffers_from_pixmap_offsets);
         x11_f.valid = true;
     } else {
+        egl_seen = true;
+        egl_f.valid = false;
         void *handle = dlopen("libEGL.so.1", RTLD_LAZY);
         if (!handle) {
             hlog("Failed to open libEGL.so.1");
@@ -827,7 +831,7 @@ static bool gl_shtex_init()
     if (data.glx) {
         // GLX on NVIDIA is all kinds of broken...
         const char *vendor = (const char*)gl_f.GetString(GL_VENDOR);
-        if (strcmp(vendor, "NVIDIA Corporation") == 0) {
+        if (vendor && strcmp(vendor, "NVIDIA Corporation") == 0) {
             return false;
         }
     }
@@ -972,8 +976,34 @@ static bool gl_init(void *display, void *surface)
     return true;
 }
 
+static bool gl_capture_disabled()
+{
+    static int disabled = 0;
+
+    if (disabled != 0) {
+        return disabled == 1;
+    }
+
+    disabled = 1;
+
+    // Always use Vulkan capture with zink
+    const char *renderer = (const char *)gl_f.GetString(GL_RENDERER);
+    if (renderer && strncmp(renderer, "zink", 4) == 0) {
+        hlog("GL capture disabled with zink");
+        return true;
+    }
+
+    disabled = -1;
+    return false;
+}
+
 static void gl_capture(void *display, void *surface)
 {
+    if (gl_capture_disabled()) {
+        data.valid = false;
+        return;
+    }
+
     capture_update_socket();
 
     if (capture_should_stop()) {
